# Mondra Visual / UI Components 

This project is solely to maintain all the UI React components for all projects under mondra umbrella, so that each project is aligned with brand guidelines & faster the web development.


## Installation

```
npm i @mondra/ui-components --save
```

## Usage
Here is a quick example to get you started, **it's all you need**:

```jsx
import * as React from 'react';
import ReactDOM from 'react-dom';
import { Input } from '@mondra/ui-components';

function App() {
  return <Input placeholder="Sample mondra text input" />;
}

ReactDOM.render(<App />, document.querySelector('#app'));
```
## Live Play Ground

[Mondra Storybook](https://mondra.com) - Variaty of UI components, style guide is documented with live examples in here.

## Contribute
Mondra team members can contribute to development of new components or modify components

### Develop
 - Clone components project from here - ProArchITSolutions@dev.azure.com/ProArchITSolutions/Mondra/_git/Mondra.UIComponents
 - `npm install` in the root directoy
 - `npm run storybook` to see the all the components in action in local enviroment
 - Checkout to your own branch `feature/<branch-name>` or `bug/<branch-name>` from main or master branch
 - What are you waiting for :smile: , go ahead and do some JSX, update  any component or add new component to `src/components` directory
 - Write stories for the respective component in `*.stories.js|ts` file
 - Add tests
 - Update CHANGELOG.md
 - Bump the version appropriately in `package.json` `X.X.X` - `Major.Minor.Patch`
 - Once changes are commit & complete the PR with title matching above version number. Also include storybook screenshot related to changes


### Build

Now master branch is upto date as per latest features or bug fixes

 - `npm run build` - Build the binaries
 - `npm publish` - This will publish the latest version of the library into npmjs.com 

 or

 - `npm run publish-lib` - which will do same as above

### Test

Each component must have set of unit tests to confirm the user experience & behaviour. Unit tests are run using Jest runner & @testing-library/react is used for tests which has gread dom testing utils API and also by extends jest API.

 - `npm run test` - To run all tests
 - `npm run test:watch` - To run tests while development

### Code smells & formatting

Each typescript, react component file is being validated or formatted before the git commit. EsLint & Prettier are doing their job to keep code validated, formatted uniform across development team. [Husky](https://typicode.github.io/husky/#/) adds more features on top of git commands to achieve this. 

 - `git commit -am "Check what happens"` - This runs both eslint & prettier formatting before commiting changes


### Potential issues while developing apps

- Issues with hooks when lib used in the react app, could be because of the multiple react instances running when we use `npm link`. This needs to be addressed

## License
See in LICENSE.md